# SEM-DESC [![PyPI](https://img.shields.io/pypi/v/sem-desc)](https://pypi.org/project/sem-desc/)

Containing basic functions (input, output, dataset, evaluation metrics) for the semantic modeling problem.
